@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.h,v 1.56.4.2 2005/10/02 18:49:57 chpe Exp $
+ *  $Id: ephy-embed.h,v 1.60 2005/11/01 12:46:06 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_H
@@ -134,6 +134,7 @@ struct _EphyEmbedIface
 					 gpointer event);
 	void	 (* popup_blocked)	(EphyEmbed *embed,
 					 const char *address,
+					 const char *target,
 					 const char *features);
 	void	 (* security_change)	(EphyEmbed *embed,
 					 EphyEmbedSecurityLevel level);
@@ -179,6 +180,11 @@ struct _EphyEmbedIface
 	int		   (* shistory_get_pos)		(EphyEmbed *embed);
 	void		   (* shistory_go_nth)		(EphyEmbed *embed,
 							 int nth);
+	void		   (* shistory_copy)		(EphyEmbed *source,
+							 EphyEmbed *dest,
+							 gboolean copy_back,
+							 gboolean copy_forward,
+							 gboolean copy_current);
 	void		   (* get_security_level)	(EphyEmbed *embed,
 						  	 EphyEmbedSecurityLevel *level,
 						  	 char **description);
@@ -259,6 +265,12 @@ int		  ephy_embed_shistory_get_pos		(EphyEmbed *embed);
 void		  ephy_embed_shistory_go_nth		(EphyEmbed *embed,
 							 int nth);
 
+void		  ephy_embed_shistory_copy		(EphyEmbed *source,
+							 EphyEmbed *dest,
+							 gboolean copy_back,
+							 gboolean copy_forward,
+							 gboolean copy_current);
+
 void		  ephy_embed_get_security_level		(EphyEmbed *embed,
 							 EphyEmbedSecurityLevel *level,
 						 	 char **description);
