@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GlobalHistory.cpp,v 1.34 2005/01/09 15:06:36 chpe Exp $
+ *  $Id: GlobalHistory.cpp,v 1.40 2005/10/31 13:22:09 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -28,9 +28,9 @@
 #include "GlobalHistory.h"
 
 #include <nsIURI.h>
-#define MOZILLA_STRICT_API
+#undef MOZILLA_INTERNAL_API
 #include <nsEmbedString.h>
-#undef MOZILLA_STRICT_API
+#define MOZILLA_INTERNAL_API 1
 
 NS_IMPL_ISUPPORTS1 (MozGlobalHistory, nsIGlobalHistory2)
 
@@ -46,23 +46,23 @@ MozGlobalHistory::~MozGlobalHistory ()
 {
 }
 
-#ifdef MOZ_NSIGLOBALHISTORY2_ADDURI_WITH_REFERRER
+#ifdef HAVE_GECKO_1_8
 /* void addURI (in nsIURI aURI, in boolean aRedirect, in boolean aToplevel, in nsIURI aReferrer); */
-NS_IMETHODIMP MozGlobalHistory::AddURI(nsIURI *aURI, PRBool aRedirect, PRBool aToplevel, nsIURI *aReferrer)
+NS_IMETHODIMP MozGlobalHistory::AddURI(nsIURI *aURI,
+				       PRBool aRedirect,
+				       PRBool aToplevel,
+				       nsIURI *aReferrer)
 #else
 /* void addURI (in nsIURI aURI, in boolean aRedirect, in boolean aToplevel); */
-NS_IMETHODIMP MozGlobalHistory::AddURI(nsIURI *aURI, PRBool aRedirect, PRBool aToplevel)
+NS_IMETHODIMP MozGlobalHistory::AddURI(nsIURI *aURI,
+				       PRBool aRedirect,
+				       PRBool aToplevel)
 #endif
 {
 	nsresult rv;
 
 	NS_ENSURE_ARG (aURI);
 
-	if (aRedirect || !aToplevel)
-	{
-		return NS_OK;
-	}
-
 	// filter out unwanted URIs such as chrome: etc
 	// The model is really if we don't know differently then add which basically
 	// means we are suppose to try all the things we know not to allow in and
@@ -70,41 +70,42 @@ NS_IMETHODIMP MozGlobalHistory::AddURI(nsIURI *aURI, PRBool aRedirect, PRBool aT
 	// against the most common case we know to allow in and go on and say yes
 	// to it.
 
-	PRBool isHTTP = PR_FALSE;
-	PRBool isHTTPS = PR_FALSE;
-
+	PRBool isHTTP = PR_FALSE, isHTTPS = PR_FALSE;
 	rv = aURI->SchemeIs("http", &isHTTP);
 	rv |= aURI->SchemeIs("https", &isHTTPS);
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
 	if (!isHTTP && !isHTTPS)
 	{
-		PRBool isJavascript, isAbout, isViewSource, isChrome, isData;
+		static const char *schemes[] = { "javascript",
+						 "data",
+						 "about",
+						 "chrome",
+						 "resource",
+						 "view-source" };
 
-	        rv = aURI->SchemeIs("javascript", &isJavascript);
-		rv |= aURI->SchemeIs("about", &isAbout);
-		rv |= aURI->SchemeIs("view-source", &isViewSource);
-		rv |= aURI->SchemeIs("chrome", &isChrome);
-		rv |= aURI->SchemeIs("data", &isData);
-		NS_ENSURE_SUCCESS(rv, NS_ERROR_FAILURE);
-
-		if (isJavascript ||isAbout || isViewSource || isChrome || isData)
+		for (PRUint32 i = 0; i < G_N_ELEMENTS (schemes); ++i)
 		{
-		      return NS_OK;
+			PRBool result = PR_FALSE;
+			if (NS_SUCCEEDED (aURI->SchemeIs (schemes[i], &result)) && result)
+			{
+				return NS_OK;
+			}
 		}
 	}
 
 	nsEmbedCString spec;
 	rv = aURI->GetSpec(spec);
-	NS_ENSURE_SUCCESS(rv, rv);
+	NS_ENSURE_TRUE (NS_SUCCEEDED(rv) && spec.Length(), rv);
 
-	ephy_history_add_page (mGlobalHistory, spec.get());
+	ephy_history_add_page (mGlobalHistory, spec.get(), aRedirect, aToplevel);
 	
 	return NS_OK;
 }
 
 /* boolean isVisited (in nsIURI aURI); */
-NS_IMETHODIMP MozGlobalHistory::IsVisited(nsIURI *aURI, PRBool *_retval)
+NS_IMETHODIMP MozGlobalHistory::IsVisited(nsIURI *aURI,
+					  PRBool *_retval)
 {
 	NS_ENSURE_ARG (aURI);
 
@@ -117,7 +118,8 @@ NS_IMETHODIMP MozGlobalHistory::IsVisited(nsIURI *aURI, PRBool *_retval)
 }
 
 /* void setPageTitle (in nsIURI aURI, in AString aTitle); */
-NS_IMETHODIMP MozGlobalHistory::SetPageTitle(nsIURI *aURI, const nsAString & aTitle)
+NS_IMETHODIMP MozGlobalHistory::SetPageTitle(nsIURI *aURI,
+					     const nsAString & aTitle)
 {
 	NS_ENSURE_ARG (aURI);
 
@@ -132,3 +134,52 @@ NS_IMETHODIMP MozGlobalHistory::SetPageTitle(nsIURI *aURI, const nsAString & aTi
 	
 	return NS_OK;
 }
+
+#ifdef HAVE_GECKO_1_9
+/* unsigned long getURIGeckoFlags(in nsIURI aURI); */
+NS_IMETHODIMP
+MozGlobalHistory::GetURIGeckoFlags(nsIURI *aURI,
+				   PRUint32* aFlags)
+{
+	nsEmbedCString spec;
+	aURI->GetSpec(spec);
+
+	EphyNode *page = ephy_history_get_page (mGlobalHistory, spec.get());
+
+	GValue value = { 0, };
+	if (page != NULL &&
+	    ephy_node_get_property (page, EPHY_NODE_PAGE_PROP_GECKO_FLAGS, &value))
+	{
+		*aFlags = (PRUint32) (gulong) g_value_get_long (&value);
+		g_value_unset (&value);
+
+		return NS_OK;
+	}
+
+	return NS_ERROR_FAILURE;
+}
+
+/* void setURIGeckoFlags(in nsIURI aURI, in unsigned long aFlags); */
+NS_IMETHODIMP
+MozGlobalHistory::SetURIGeckoFlags(nsIURI *aURI,
+				   PRUint32 aFlags)
+{
+	nsEmbedCString spec;
+	aURI->GetSpec(spec);
+
+	EphyNode *page = ephy_history_get_page (mGlobalHistory, spec.get());
+	if (page != NULL)
+	{
+		GValue value = { 0, };
+
+		g_value_init (&value, G_TYPE_LONG);
+		g_value_set_long (&value, (long) (gulong) aFlags);
+		ephy_node_set_property (page, EPHY_NODE_PAGE_PROP_GECKO_FLAGS, &value);
+		g_value_unset (&value);
+
+		return NS_OK;
+	}
+
+	return NS_ERROR_FAILURE;
+}
+#endif /* HAVE_GECKO_1_9 */
