@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSClientAuthDialogs.cpp,v 1.22.2.1 2005/04/07 11:46:32 chpe Exp $
+ *  $Id: GtkNSSClientAuthDialogs.cpp,v 1.25 2005/11/01 11:15:55 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -26,6 +26,7 @@
 
 #include "EphyUtils.h"
 
+#include <nsIDOMWindow.h>
 #include <nsIServiceManager.h>
 #include <nsIInterfaceRequestor.h>
 #include <nsIInterfaceRequestorUtils.h>
@@ -199,7 +200,7 @@ GtkNSSClientAuthDialogs::ChooseCertificate (nsIInterfaceRequestor *ctx,
 	NS_UTF16ToCString (nsEmbedString (cn),
 			   NS_CSTRING_ENCODING_UTF8, utf8_cn);
 
-	msg = g_markup_printf_escaped (_("Choose a certificate to present as identification to \"%s\"."),
+	msg = g_markup_printf_escaped (_("Choose a certificate to present as identification to “%s”."),
 				       utf8_cn.get());
 	markup_text = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s",
 				       _("Select a certificate to identify yourself."),
