@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: print-dialog.c,v 1.42.4.2 2005/10/02 18:09:11 chpe Exp $
+ *  $Id: print-dialog.c,v 1.47 2005/11/01 11:15:55 chpe Exp $
  */
 
 #include "config.h"
@@ -80,14 +80,6 @@ EphyDialogProperty setup_props [] =
 	{ NULL }
 };
 
-void ephy_print_dialog_response_cb		(GtkDialog *dialog,
-						 int response,
-						 EmbedPrintInfo *info);
-void ephy_print_setup_dialog_close_button_cb	(GtkWidget *widget,
-						 EphyDialog *dialog);
-void ephy_print_setup_dialog_help_button_cb	(GtkWidget *widget,
-						 EphyDialog *dialog);
-
 void
 ephy_print_info_free (EmbedPrintInfo *info)
 {
@@ -193,7 +185,7 @@ ephy_print_get_print_info (void)
 	return info;
 }
 
-void
+static void
 ephy_print_dialog_response_cb (GtkDialog *dialog,
 			       int response,
 			       EmbedPrintInfo *info)
@@ -283,7 +275,7 @@ ephy_print_verify_postscript (GnomePrintDialog *print_dialog)
                         _("Printing is not supported on this printer"));
                 gtk_message_dialog_format_secondary_text (
                         GTK_MESSAGE_DIALOG (dialog),
-                        _("You were trying to print to a printer using the \"%s\" driver. This program requires a PostScript printer driver."),
+                        _("You were trying to print to a printer using the “%s” driver. This program requires a PostScript printer driver."),
                         gnome_print_config_get (
                                 config, (guchar *)"Settings.Engine.Backend.Driver"));
         }
@@ -346,18 +338,18 @@ ephy_print_do_print_and_free (EmbedPrintInfo *info)
 						  info);
 }
 
-void
-ephy_print_setup_dialog_close_button_cb (GtkWidget *widget,
-					 EphyDialog *dialog)
+static void
+ephy_print_setup_dialog_response_cb (GtkWidget *widget,
+				     int response,
+				     EphyDialog *dialog)
 {
-	g_object_unref (dialog);
-}
+	if (response == GTK_RESPONSE_HELP)
+	{
+		ephy_gui_help (GTK_WINDOW (widget), "epiphany", "using-print-setup");
+		return;
+	}
 
-void
-ephy_print_setup_dialog_help_button_cb (GtkWidget *widget,
-					 EphyDialog *dialog)
-{
-	ephy_gui_help (gtk_widget_get_toplevel (widget), "epiphany", "using-print-setup");
+	g_object_unref (dialog);
 }
 
 static GtkWidget *
@@ -483,7 +475,9 @@ ephy_print_setup_dialog_new (void)
 
 	window = ephy_dialog_get_control (dialog, setup_props[SETUP_WINDOW_PROP].id);
 	gtk_window_set_icon_name (GTK_WINDOW (window), STOCK_PRINT_SETUP);
-	
+	g_signal_connect (window, "response",
+			  G_CALLBACK (ephy_print_setup_dialog_response_cb), dialog);
+
 	paper_selector_hbox = ephy_dialog_get_control (dialog,
 						setup_props[PAPER_SELECTOR_PROP].id);
 	gtk_box_pack_start_defaults (GTK_BOX (paper_selector_hbox),
