@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-file-helpers.c,v 1.32 2005/08/20 22:25:48 chpe Exp $
+ *  $Id: ephy-file-helpers.c,v 1.34 2005/11/10 21:32:32 crispin Exp $
  */
 
 #include "config.h"
@@ -107,6 +107,48 @@ ephy_file_downloads_dir (void)
 	return downloads_dir;
 }
 
+char *
+ephy_file_get_downloads_dir (void)
+{
+	char *download_dir, *expanded;
+
+	download_dir = eel_gconf_get_string (CONF_STATE_DOWNLOAD_DIR);
+
+	if (download_dir && strcmp (download_dir, "Downloads") == 0)
+	{
+		g_free (download_dir);
+		download_dir = ephy_file_downloads_dir ();
+	}
+  	else if (download_dir && strcmp (download_dir, "Desktop") == 0)
+	{
+		g_free (download_dir);
+		download_dir = ephy_file_desktop_dir ();
+	}  
+	else if (download_dir)
+	{
+		char *converted_dp;
+
+		converted_dp = g_filename_from_utf8 (download_dir, -1, NULL, NULL, NULL);
+		g_free (download_dir);
+		download_dir = converted_dp;
+	}
+
+	/* Emergency download destination */
+	if (download_dir == NULL)
+	{
+		const char *home_dir;
+		home_dir = g_get_home_dir ();
+		download_dir = g_strdup (home_dir != NULL ? home_dir : "/");
+	}
+
+	g_return_val_if_fail (download_dir != NULL, NULL);
+
+	expanded = gnome_vfs_expand_initial_tilde (download_dir);
+	g_free (download_dir);
+
+	return expanded;
+}
+
 char *
 ephy_file_desktop_dir (void)
 {
