@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-lockdown.c,v 1.4 2005/07/26 14:41:39 chpe Exp $
+ *  $Id: ephy-lockdown.c,v 1.8 2005/10/21 16:15:09 philipl Exp $
  */
 
 #include "config.h"
@@ -65,22 +65,22 @@ static GObjectClass *parent_class = NULL;
 
 static int
 find_name (GtkActionGroup *action_group,
-           const char *name)
+	   const char *name)
 {
-        return strcmp (gtk_action_group_get_name (action_group), name);
+	return strcmp (gtk_action_group_get_name (action_group), name);
 }
 
 static GtkActionGroup *
 find_action_group (GtkUIManager *manager,
 		   const char *name)
 {
-        GList *list, *element;
+	GList *list, *element;
 
-        list = gtk_ui_manager_get_action_groups (manager);
-        element = g_list_find_custom (list, name, (GCompareFunc) find_name);
-        g_return_val_if_fail (element != NULL, NULL);
+	list = gtk_ui_manager_get_action_groups (manager);
+	element = g_list_find_custom (list, name, (GCompareFunc) find_name);
+	g_return_val_if_fail (element != NULL, NULL);
 
-        return GTK_ACTION_GROUP (element->data);
+	return GTK_ACTION_GROUP (element->data);
 }
 
 static void
@@ -108,7 +108,8 @@ update_location_editable (EphyWindow *window,
 
 			address = ephy_embed_get_location (embed, TRUE);
 			ephy_toolbar_set_location (EPHY_TOOLBAR (toolbar), address, NULL);
-			ephy_tab_set_typed_address (tab, NULL);
+			ephy_tab_set_typed_address (tab, NULL,
+						    EPHY_TAB_ADDRESS_EXPIRE_CURRENT);
 			g_free (address);
 		}
 	}
@@ -148,10 +149,6 @@ update_window (EphyWindow *window,
 	action = gtk_action_group_get_action (action_group, "ViewToolbar");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, !writable);
 
-	writable = eel_gconf_key_is_writable (CONF_WINDOWS_SHOW_BOOKMARKS_BAR);
-	action = gtk_action_group_get_action (action_group, "ViewBookmarksBar");
-	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, !writable);
-
 	writable = eel_gconf_key_is_writable (CONF_WINDOWS_SHOW_STATUSBAR);
 	action = gtk_action_group_get_action (action_group, "ViewStatusbar");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, !writable);
@@ -161,20 +158,14 @@ update_window (EphyWindow *window,
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
 	action = gtk_action_group_get_action (toolbar_action_group, "Location");
 	update_location_editable (window, action, !disabled);
-	action = gtk_action_group_get_action (action_group, "GoUp");
-	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
 	action = gtk_action_group_get_action (toolbar_action_group, "NavigationUp");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
 
 	disabled = eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_HISTORY);
 	action = gtk_action_group_get_action (action_group, "GoHistory");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
-	action = gtk_action_group_get_action (action_group, "GoBack");
-	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
 	action = gtk_action_group_get_action (toolbar_action_group, "NavigationBack");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
-	action = gtk_action_group_get_action (action_group, "GoForward");
-	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
 	action = gtk_action_group_get_action (toolbar_action_group, "NavigationForward");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
 
@@ -197,8 +188,6 @@ update_window (EphyWindow *window,
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
 	action = gtk_action_group_get_action (popups_action_group, "DownloadLinkAs");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
-	action = gtk_action_group_get_action (popups_action_group, "SaveBackgroundAs");
-	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
 	action = gtk_action_group_get_action (popups_action_group, "SaveImageAs");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
 	writable = eel_gconf_key_is_writable (CONF_DESKTOP_BG_PICTURE);
