@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tabs-menu.c,v 1.38 2005/09/28 13:36:49 chpe Exp $
+ *  $Id: ephy-tabs-menu.c,v 1.39 2005/11/08 12:46:43 chpe Exp $
  */
 
 #include "config.h"
@@ -326,7 +326,7 @@ ephy_tabs_menu_class_init (EphyTabsMenuClass *klass)
 							      "Window",
 							      "Parent window",
 							      EPHY_TYPE_WINDOW,
-							      G_PARAM_READWRITE |
+							      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
 							      G_PARAM_CONSTRUCT_ONLY));
 
 	g_type_class_add_private (object_class, sizeof (EphyTabsMenuPrivate));
