@@ -1,6 +1,6 @@
- /*
+/*
  *  Copyright (C) 200-2003 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright (C) 2003, 2004, 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: prefs-dialog.c,v 1.114 2005/08/07 21:47:11 chpe Exp $
+ *  $Id: prefs-dialog.c,v 1.118 2005/10/30 22:58:12 chpe Exp $
  */
 
 #include "config.h"
@@ -57,36 +57,15 @@
 #include <gtk/gtklabel.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtknotebook.h>
+#include <gtk/gtkfilechooserbutton.h>
 #include <string.h>
 
 #define CONF_FONTS_FOR_LANGUAGE	"/apps/epiphany/dialogs/preferences_font_language"
+#define DOWNLOAD_BUTTON_WIDTH	8
 
 static void prefs_dialog_class_init	(PrefsDialogClass *klass);
 static void prefs_dialog_init		(PrefsDialog *pd);
 
-/* Glade callbacks */
-void prefs_clear_cache_button_clicked_cb	(GtkWidget *button,
-						 gpointer data);
-void prefs_dialog_response_cb			(GtkDialog *widget,
-						 gint response_id,
-						 EphyDialog *dialog);
-void prefs_homepage_current_button_clicked_cb	(GtkWidget *button,
-						 EphyDialog *dialog);
-void prefs_homepage_blank_button_clicked_cb	(GtkWidget *button,
-						 EphyDialog *dialog);
-void prefs_language_more_button_clicked_cb	(GtkWidget *button,
-						 EphyDialog *dialog);
-void prefs_download_path_button_clicked_cb	(GtkWidget *button,
-						 PrefsDialog *dialog);
-void language_editor_add_button_clicked_cb	(GtkWidget *button,
-						 PrefsDialog *pd);
-void language_editor_remove_button_clicked_cb	(GtkWidget *button,
-						 PrefsDialog *pd);
-void language_editor_up_button_clicked_cb	(GtkWidget *button,
-						 PrefsDialog *pd);
-void language_editor_down_button_clicked_cb	(GtkWidget *button,
-						 PrefsDialog *pd);
-
 #include "languages.h"
 
 static const char * const cookies_accept_enum [] =
@@ -138,7 +117,7 @@ enum
 	HOMEPAGE_CURRENT_PROP,
 	HOMEPAGE_BLANK_PROP,
 	AUTO_OPEN_PROP,
-	DOWNLOAD_PATH_BUTTON_PROP,
+	DOWNLOAD_PATH_HBOX_PROP,
 
 	/* Fonts and Colors */
 	FONTS_LANGUAGE_PROP,
@@ -156,6 +135,7 @@ enum
 	ALLOW_JS_PROP,
 	ACCEPT_COOKIES_PROP,
 	DISK_CACHE_PROP,
+	CLEAR_CACHE_BUTTON_PROP,
 
 	/* Language */
 	AUTO_ENCODING_PROP,
@@ -180,7 +160,7 @@ EphyDialogProperty properties [] =
 	{ "homepage_current_button",		NULL,			  PT_NORMAL,	0 },
 	{ "homepage_blank_button",		NULL,			  PT_NORMAL,	0 },
 	{ "automatic_downloads_checkbutton",	CONF_AUTO_DOWNLOADS,      PT_AUTOAPPLY,	0 },
-	{ "download_path_button",		NULL,			  PT_NORMAL,	0 },
+	{ "download_button_hbox",		NULL,			  PT_NORMAL,	0 },
 
 	/* Fonts and Colors */
 	{ "fonts_language_combo",	CONF_FONTS_FOR_LANGUAGE,	PT_AUTOAPPLY,	G_TYPE_STRING },
@@ -198,6 +178,7 @@ EphyDialogProperty properties [] =
 	{ "enable_javascript_checkbutton",	CONF_SECURITY_JAVASCRIPT_ENABLED, PT_AUTOAPPLY, 0 },
 	{ "cookies_radiobutton",		CONF_SECURITY_COOKIES_ACCEPT,	  PT_AUTOAPPLY, G_TYPE_STRING },
 	{ "disk_cache_spin",			CONF_NETWORK_CACHE_SIZE,	  PT_AUTOAPPLY, 0 },
+	{ "clear_cache_button",			NULL,				  PT_NORMAL,	0 },
 
 	/* Languages */
 	{ "auto_encoding_combo",	CONF_LANGUAGE_AUTODETECT_ENCODING,	PT_AUTOAPPLY,	G_TYPE_STRING },
@@ -252,7 +233,6 @@ enum
 
 struct PrefsDialogPrivate
 {
-	GtkWidget *download_dir_chooser;
 	GtkTreeView *lang_treeview;
 	GtkTreeModel *lang_model;
 	EphyDialog *add_lang_dialog;
@@ -264,10 +244,6 @@ struct PrefsDialogPrivate
 	GHashTable *iso_3166_table;
 };
 
-/* gtk+' gettext domain */
-#define GTK_DOMAIN "gtk20"
-#define DGETTEXT_GTK_(x) dgettext(GTK_DOMAIN, x)
-
 static GObjectClass *parent_class = NULL;
 
 GType
@@ -311,13 +287,6 @@ prefs_dialog_finalize (GObject *object)
 		g_object_unref (dialog->priv->add_lang_dialog);
 	}
 
-	if (dialog->priv->download_dir_chooser != NULL)
-	{
-		g_object_remove_weak_pointer
-			(G_OBJECT (dialog->priv->download_dir_chooser),
-			 (gpointer *) &dialog->priv->download_dir_chooser);
-	}
-
 	g_hash_table_destroy (dialog->priv->iso_639_table);
 	g_hash_table_destroy (dialog->priv->iso_3166_table);
 
@@ -901,7 +870,7 @@ setup_add_language_dialog (PrefsDialog *pd)
 	return dialog;
 }
 
-void
+static void
 language_editor_add_button_clicked_cb (GtkWidget *button,
 				       PrefsDialog *pd)
 {
@@ -917,7 +886,7 @@ language_editor_add_button_clicked_cb (GtkWidget *button,
 	ephy_dialog_show (pd->priv->add_lang_dialog);
 }
 
-void
+static void
 language_editor_remove_button_clicked_cb (GtkWidget *button,
 					  PrefsDialog *pd)
 {
@@ -936,7 +905,7 @@ language_editor_remove_button_clicked_cb (GtkWidget *button,
 	language_editor_update_buttons (pd);
 }
 
-void
+static void
 language_editor_up_button_clicked_cb (GtkWidget *button,
 				      PrefsDialog *pd)
 {
@@ -968,7 +937,7 @@ language_editor_up_button_clicked_cb (GtkWidget *button,
 	language_editor_update_buttons (pd);
 }
 
-void
+static void
 language_editor_down_button_clicked_cb (GtkWidget *button,
 					PrefsDialog *pd)
 {
@@ -1036,6 +1005,15 @@ create_language_section (EphyDialog *dialog)
 		 properties[LANGUAGE_DOWN_BUTTON_PROP].id, &pd->priv->lang_down_button,
 		 NULL);
 
+	g_signal_connect (pd->priv->lang_add_button, "clicked",
+			  G_CALLBACK (language_editor_add_button_clicked_cb), dialog);
+	g_signal_connect (pd->priv->lang_remove_button, "clicked",
+			  G_CALLBACK (language_editor_remove_button_clicked_cb), dialog);
+	g_signal_connect (pd->priv->lang_up_button, "clicked",
+			  G_CALLBACK (language_editor_up_button_clicked_cb), dialog);
+	g_signal_connect (pd->priv->lang_down_button, "clicked",
+			  G_CALLBACK (language_editor_down_button_clicked_cb), dialog);
+
 	/* setup the languages treeview */
 	pd->priv->lang_treeview = treeview;
 
@@ -1126,151 +1104,91 @@ create_language_section (EphyDialog *dialog)
 	g_slist_free (ulist);
 }
 
-static char*
-get_download_button_label (void)
+static void
+download_path_changed_cb (GtkFileChooser *button)
 {
-	char *key, *label, *downloads_path, *converted_dp;
+	char *dir, *downloads_dir, *desktop_dir;
 
-	key = eel_gconf_get_string (CONF_STATE_DOWNLOAD_DIR);
+	/* FIXME: use _uri variant when we support downloading 
+	 * to gnome-vfs remote locations
+	 */
+	dir = gtk_file_chooser_get_filename (button);
+	if (dir == NULL) return;
 
-	downloads_path = ephy_file_downloads_dir ();
-	converted_dp = g_filename_to_utf8 (downloads_path, -1, NULL, NULL, NULL);
+	downloads_dir = ephy_file_downloads_dir ();
+	desktop_dir = ephy_file_desktop_dir ();
+	g_return_if_fail (downloads_dir != NULL && desktop_dir != NULL);
 
-	if (key == NULL || g_utf8_collate (key, "~") == 0)
+	if (strcmp (dir, downloads_dir) == 0)
 	{
-		label = g_strdup (DGETTEXT_GTK_("Home"));
+		eel_gconf_set_string (CONF_STATE_DOWNLOAD_DIR, "Downloads");
 	}
-	else if ((converted_dp != NULL && g_utf8_collate (key, converted_dp) == 0) ||
-		 g_utf8_collate (key, "Downloads") == 0)
+	else if (strcmp (dir, desktop_dir) == 0)
 	{
-		label = g_strdup (_("Downloads"));
-	}
-	else if (g_utf8_collate (key, "~/Desktop") == 0 ||
-	         g_utf8_collate (key, "Desktop") == 0)
-	{
-		label = g_strdup (DGETTEXT_GTK_("Desktop"));
+		eel_gconf_set_string (CONF_STATE_DOWNLOAD_DIR, "Desktop");
 	}
 	else
 	{
-		label = g_strdup (key);
+		eel_gconf_set_path (CONF_STATE_DOWNLOAD_DIR, dir);
 	}
 
-	g_free (downloads_path);
-	g_free (converted_dp);
-	g_free (key);
-
-	return label;
+	g_free (dir);
+	g_free (downloads_dir);
+	g_free (desktop_dir);
 }
-	
+
 static void
-create_download_path_label (EphyDialog *dialog)
+create_download_path_button (EphyDialog *dialog)
 {
-	GtkWidget *button, *label;
+	GtkWidget *parent, *hbox, *button;
+	EphyFileChooser *fc;
 	char *dir;
 
-	button = ephy_dialog_get_control (dialog, properties[DOWNLOAD_PATH_BUTTON_PROP].id);
-	
-	dir = get_download_button_label ();
-	label = gtk_label_new (dir);
-	gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_START);
-	gtk_container_add (GTK_CONTAINER (button), label);
-	g_free (dir);
-	gtk_widget_show (label);
+	dir = ephy_file_get_downloads_dir ();
+
+	ephy_dialog_get_controls (dialog,
+				  properties[DOWNLOAD_PATH_HBOX_PROP].id, &hbox,
+				  properties[WINDOW_PROP].id, &parent,
+				  NULL);
+
+	fc = ephy_file_chooser_new (_("Select a Directory"),
+				    parent,
+				    GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
+				    NULL, EPHY_FILE_FILTER_NONE);
+
+	/* Unset the destroy-with-parent, since gtkfilechooserbutton doesn't expect this */
+	gtk_window_set_destroy_with_parent (GTK_WINDOW (fc), FALSE);
+
+	button = gtk_file_chooser_button_new_with_dialog (GTK_WIDGET (fc));
+	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (button), dir);
+	gtk_file_chooser_button_set_width_chars (GTK_FILE_CHOOSER_BUTTON (button),
+						 DOWNLOAD_BUTTON_WIDTH);
+	g_signal_connect (button, "current-folder-changed",
+			  G_CALLBACK (download_path_changed_cb), dialog);
+	gtk_box_pack_start (GTK_BOX (hbox), button, TRUE, TRUE, 0);
+	gtk_widget_show (button);
 
 	gtk_widget_set_sensitive (button, eel_gconf_key_is_writable (CONF_STATE_DOWNLOAD_DIR));
+	g_free (dir);
 }
-	
+
 static void
-prefs_dialog_init (PrefsDialog *pd)
-{
-	EphyDialog *dialog = EPHY_DIALOG (pd);
-	EphyEncodings *encodings;
-	GtkWidget *window, *curr_button, *blank_button;
-	GtkWidget *variable_combo, *monospace_combo;
-	GtkCellRenderer *renderer;
-	gboolean sensitive;
-
-	pd->priv = EPHY_PREFS_DIALOG_GET_PRIVATE (pd);
-
-#ifdef ENABLE_NLS
-        /* Initialize the control centre domain */
-        bindtextdomain (GTK_DOMAIN, GNOMELOCALEDIR);
-        bind_textdomain_codeset(GTK_DOMAIN, "UTF-8");
-#endif
-
-	ephy_dialog_construct (dialog,
-			       properties,
-			       ephy_file ("prefs-dialog.glade"),
-			       "prefs_dialog",
-			       NULL);
-
-	ephy_dialog_add_enum (dialog, properties[ACCEPT_COOKIES_PROP].id,
-			      G_N_ELEMENTS (cookies_accept_enum), cookies_accept_enum);
-
-	ephy_dialog_get_controls
-		(dialog,
-		 properties[WINDOW_PROP].id, &window,
-		 properties[HOMEPAGE_CURRENT_PROP].id, &curr_button,
-		 properties[HOMEPAGE_BLANK_PROP].id, &blank_button,
-		 properties[VARIABLE_PROP].id, &variable_combo,
-		 properties[MONOSPACE_PROP].id, &monospace_combo,
-		 NULL);
-
-	gtk_window_set_icon_name (GTK_WINDOW (window), GTK_STOCK_PREFERENCES);
-
-	/* set homepage button sensitivity */
-	sensitive = eel_gconf_key_is_writable (CONF_GENERAL_HOMEPAGE);
-	gtk_widget_set_sensitive (curr_button, sensitive);
-	gtk_widget_set_sensitive (blank_button, sensitive);
-
-        renderer = gtk_cell_renderer_text_new ();
-        gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (variable_combo), renderer, TRUE);
-        gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (variable_combo), renderer,
-                                        "text", 0,
-                                        NULL);
-	ephy_dialog_set_data_column (dialog, properties[VARIABLE_PROP].id, 0);
-        renderer = gtk_cell_renderer_text_new ();
-        gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (monospace_combo), renderer, TRUE);
-        gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (monospace_combo), renderer,
-                                        "text", 0,
-                                        NULL);
-	ephy_dialog_set_data_column (dialog, properties[MONOSPACE_PROP].id, 0);
-
-	create_fonts_language_menu (dialog);
-
-	encodings = EPHY_ENCODINGS (ephy_embed_shell_get_encodings
-					(EPHY_EMBED_SHELL (ephy_shell)));
-
-	create_node_combo (dialog, DEFAULT_ENCODING_PROP, encodings,
-			   ephy_encodings_get_all (encodings),
-			   CONF_LANGUAGE_DEFAULT_ENCODING, "ISO-8859-1");
-	create_node_combo (dialog, AUTO_ENCODING_PROP, encodings,
-			   ephy_encodings_get_detectors (encodings),
-			   CONF_LANGUAGE_AUTODETECT_ENCODING, "");
-
-	create_language_section	(dialog);
-
-	create_download_path_label (dialog);
-}
-
-void
 prefs_dialog_response_cb (GtkDialog *widget,
-			  gint response_id,
+			  int response,
 			  EphyDialog *dialog)
 {
-	if (response_id == GTK_RESPONSE_CLOSE)
-	{
-		g_object_unref (dialog);
-	}
-	else if (response_id == GTK_RESPONSE_HELP)
+	if (response == GTK_RESPONSE_HELP)
 	{
 		prefs_dialog_show_help (dialog);
+		return;
 	}
+		
+	g_object_unref (dialog);
 }
 
-void
+static void
 prefs_clear_cache_button_clicked_cb (GtkWidget *button,
-				     gpointer data)
+				     PrefsDialog *dialog)
 {
 	EphyEmbedShell *shell;
 	EphyEmbedSingle *single;
@@ -1297,7 +1215,7 @@ set_homepage_entry (EphyDialog *dialog,
 	g_value_unset (&value);
 }
 
-void
+static void
 prefs_homepage_current_button_clicked_cb (GtkWidget *button,
 					  EphyDialog *dialog)
 {
@@ -1317,66 +1235,87 @@ prefs_homepage_current_button_clicked_cb (GtkWidget *button,
 	set_homepage_entry (dialog, ephy_tab_get_address (tab));
 }
 
-void
+static void
 prefs_homepage_blank_button_clicked_cb (GtkWidget *button,
 					EphyDialog *dialog)
 {
 	set_homepage_entry (dialog, NULL);
 }
-
 static void
-download_path_response_cb (GtkDialog *fc, gint response, EphyDialog *dialog)
+prefs_dialog_init (PrefsDialog *pd)
 {
-	if (response == GTK_RESPONSE_ACCEPT)
-	{
-		char *dir;
+	EphyDialog *dialog = EPHY_DIALOG (pd);
+	EphyEncodings *encodings;
+	GtkWidget *window, *curr_button, *blank_button;
+	GtkWidget *variable_combo, *monospace_combo, *clear_cache_button;
+	GtkCellRenderer *renderer;
+	gboolean sensitive;
 
-		dir = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (fc));
-		if (dir != NULL)
-		{
-			GtkWidget *button;
-			char *label;
+	pd->priv = EPHY_PREFS_DIALOG_GET_PRIVATE (pd);
 
-			eel_gconf_set_path (CONF_STATE_DOWNLOAD_DIR, dir);
+	ephy_dialog_construct (dialog,
+			       properties,
+			       ephy_file ("prefs-dialog.glade"),
+			       "prefs_dialog",
+			       NULL);
 
-			button = ephy_dialog_get_control (dialog, properties[DOWNLOAD_PATH_BUTTON_PROP].id);
-			label = get_download_button_label ();
-			gtk_label_set_text (GTK_LABEL (GTK_BIN (button)->child), label);
+	ephy_dialog_add_enum (dialog, properties[ACCEPT_COOKIES_PROP].id,
+			      G_N_ELEMENTS (cookies_accept_enum), cookies_accept_enum);
 
-			g_free (dir);
-			g_free (label);
-		}
-	}
+	ephy_dialog_get_controls
+		(dialog,
+		 properties[WINDOW_PROP].id, &window,
+		 properties[HOMEPAGE_CURRENT_PROP].id, &curr_button,
+		 properties[HOMEPAGE_BLANK_PROP].id, &blank_button,
+		 properties[VARIABLE_PROP].id, &variable_combo,
+		 properties[MONOSPACE_PROP].id, &monospace_combo,
+		 properties[CLEAR_CACHE_BUTTON_PROP].id, &clear_cache_button,
+		 NULL);
 
-	gtk_widget_destroy (GTK_WIDGET (fc));
-}
-
-void
-prefs_download_path_button_clicked_cb (GtkWidget *button,
-				       PrefsDialog *dialog)
-{
-	if (dialog->priv->download_dir_chooser == NULL)
-	{
-		GtkWidget *parent;
-		EphyFileChooser *fc;
-
-		parent = ephy_dialog_get_control
-			(EPHY_DIALOG (dialog), properties[WINDOW_PROP].id);
-	
-		fc = ephy_file_chooser_new (_("Select a directory"),
-					    GTK_WIDGET (parent),
-					    GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
-					    NULL, EPHY_FILE_FILTER_NONE);
-		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (fc),
-						     g_get_home_dir ());
-
-		g_signal_connect (GTK_DIALOG (fc), "response",
-				    G_CALLBACK (download_path_response_cb),
-				    dialog);
-		dialog->priv->download_dir_chooser = GTK_WIDGET (fc);
-		g_object_add_weak_pointer
-			(G_OBJECT (fc), (gpointer *) &dialog->priv->download_dir_chooser);
-	}
-
-	gtk_widget_show (dialog->priv->download_dir_chooser);
+	gtk_window_set_icon_name (GTK_WINDOW (window), GTK_STOCK_PREFERENCES);
+
+	g_signal_connect (window, "response",
+			  G_CALLBACK (prefs_dialog_response_cb), dialog);
+
+	g_signal_connect (curr_button, "clicked",
+			  G_CALLBACK (prefs_homepage_current_button_clicked_cb), dialog);
+	g_signal_connect (blank_button, "clicked",
+			  G_CALLBACK (prefs_homepage_blank_button_clicked_cb), dialog);
+
+	/* set homepage button sensitivity */
+	sensitive = eel_gconf_key_is_writable (CONF_GENERAL_HOMEPAGE);
+	gtk_widget_set_sensitive (curr_button, sensitive);
+	gtk_widget_set_sensitive (blank_button, sensitive);
+
+        renderer = gtk_cell_renderer_text_new ();
+        gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (variable_combo), renderer, TRUE);
+        gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (variable_combo), renderer,
+                                        "text", 0,
+                                        NULL);
+	ephy_dialog_set_data_column (dialog, properties[VARIABLE_PROP].id, 0);
+        renderer = gtk_cell_renderer_text_new ();
+        gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (monospace_combo), renderer, TRUE);
+        gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (monospace_combo), renderer,
+                                        "text", 0,
+                                        NULL);
+	ephy_dialog_set_data_column (dialog, properties[MONOSPACE_PROP].id, 0);
+
+	create_fonts_language_menu (dialog);
+
+	g_signal_connect (clear_cache_button, "clicked",
+			  G_CALLBACK (prefs_clear_cache_button_clicked_cb), dialog);
+
+	encodings = EPHY_ENCODINGS (ephy_embed_shell_get_encodings
+					(EPHY_EMBED_SHELL (ephy_shell)));
+
+	create_node_combo (dialog, DEFAULT_ENCODING_PROP, encodings,
+			   ephy_encodings_get_all (encodings),
+			   CONF_LANGUAGE_DEFAULT_ENCODING, "ISO-8859-1");
+	create_node_combo (dialog, AUTO_ENCODING_PROP, encodings,
+			   ephy_encodings_get_detectors (encodings),
+			   CONF_LANGUAGE_AUTODETECT_ENCODING, "");
+
+	create_language_section	(dialog);
+
+	create_download_path_button (dialog);
 }
